==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppPrivateEndpointConnectionSlot.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.kotlin.outputs.ArmIdWrapperResponse
import com.pulumi.azurenative.web.kotlin.outputs.PrivateLinkConnectionStateResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.web.kotlin.outputs.ArmIdWrapperResponse.Companion.toKotlin as armIdWrapperResponseToKotlin
import com.pulumi.azurenative.web.kotlin.outputs.PrivateLinkConnectionStateResponse.Companion.toKotlin as privateLinkConnectionStateResponseToKotlin

/**
 * Builder for [WebAppPrivateEndpointConnectionSlot].
 */
@PulumiTagMarker
public class WebAppPrivateEndpointConnectionSlotResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppPrivateEndpointConnectionSlotArgs =
        WebAppPrivateEndpointConnectionSlotArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend
    fun args(block: suspend WebAppPrivateEndpointConnectionSlotArgsBuilder.() -> Unit) {
        val builder = WebAppPrivateEndpointConnectionSlotArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebAppPrivateEndpointConnectionSlot {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppPrivateEndpointConnectionSlot(builtJavaResource)
    }
}

/**
 * Remote Private Endpoint Connection ARM resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2023-01-01.
 * ## Example Usage
 * ### Approves or rejects a private endpoint connection for a site.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webAppPrivateEndpointConnectionSlot = new AzureNative.Web.WebAppPrivateEndpointConnectionSlot("webAppPrivateEndpointConnectionSlot", new()
 *     {
 *         Name = "testSite",
 *         PrivateEndpointConnectionName = "connection",
 *         PrivateLinkServiceConnectionState = new AzureNative.Web.Inputs.PrivateLinkConnectionStateArgs
 *         {
 *             ActionsRequired = "",
 *             Description = "Approved by admin.",
 *             Status = "Approved",
 *         },
 *         ResourceGroupName = "rg",
 *         Slot = "stage",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewWebAppPrivateEndpointConnectionSlot(ctx, "webAppPrivateEndpointConnectionSlot", &web.WebAppPrivateEndpointConnectionSlotArgs{
 * 			Name:                          pulumi.String("testSite"),
 * 			PrivateEndpointConnectionName: pulumi.String("connection"),
 * 			PrivateLinkServiceConnectionState: &web.PrivateLinkConnectionStateArgs{
 * 				ActionsRequired: pulumi.String(""),
 * 				Description:     pulumi.String("Approved by admin."),
 * 				Status:          pulumi.String("Approved"),
 * 			},
 * 			ResourceGroupName: pulumi.String("rg"),
 * 			Slot:              pulumi.String("stage"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot;
 * import com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlotArgs;
 * import com.pulumi.azurenative.web.inputs.PrivateLinkConnectionStateArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webAppPrivateEndpointConnectionSlot = new WebAppPrivateEndpointConnectionSlot("webAppPrivateEndpointConnectionSlot", WebAppPrivateEndpointConnectionSlotArgs.builder()
 *             .name("testSite")
 *             .privateEndpointConnectionName("connection")
 *             .privateLinkServiceConnectionState(PrivateLinkConnectionStateArgs.builder()
 *                 .actionsRequired("")
 *                 .description("Approved by admin.")
 *                 .status("Approved")
 *                 .build())
 *             .resourceGroupName("rg")
 *             .slot("stage")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppPrivateEndpointConnectionSlot connection /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/privateEndpointConnections/{privateEndpointConnectionName}
 * ```
 */
public class WebAppPrivateEndpointConnectionSlot internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot,
) : KotlinCustomResource(javaResource, WebAppPrivateEndpointConnectionSlotMapper) {
    /**
     * Private IPAddresses mapped to the remote private endpoint
     */
    public val ipAddresses: Output<List<String>>?
        get() = javaResource.ipAddresses().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0
                })
            }).orElse(null)
        })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * PrivateEndpoint of a remote private endpoint connection
     */
    public val privateEndpoint: Output<ArmIdWrapperResponse>?
        get() = javaResource.privateEndpoint().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> armIdWrapperResponseToKotlin(args0) })
            }).orElse(null)
        })

    /**
     * The state of a private link connection
     */
    public val privateLinkServiceConnectionState: Output<PrivateLinkConnectionStateResponse>?
        get() = javaResource.privateLinkServiceConnectionState().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    privateLinkConnectionStateResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppPrivateEndpointConnectionSlotMapper :
    ResourceMapper<WebAppPrivateEndpointConnectionSlot> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot::class == javaResource::class

    override fun map(javaResource: Resource): WebAppPrivateEndpointConnectionSlot =
        WebAppPrivateEndpointConnectionSlot(
            javaResource as
                com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot,
        )
}

/**
 * @see [WebAppPrivateEndpointConnectionSlot].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppPrivateEndpointConnectionSlot].
 */
public suspend fun webAppPrivateEndpointConnectionSlot(
    name: String,
    block: suspend WebAppPrivateEndpointConnectionSlotResourceBuilder.() -> Unit,
):
    WebAppPrivateEndpointConnectionSlot {
    val builder = WebAppPrivateEndpointConnectionSlotResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppPrivateEndpointConnectionSlot].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppPrivateEndpointConnectionSlot(name: String): WebAppPrivateEndpointConnectionSlot {
    val builder = WebAppPrivateEndpointConnectionSlotResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppPrivateEndpointConnectionSlot.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.kotlin.outputs.ArmIdWrapperResponse
import com.pulumi.azurenative.web.kotlin.outputs.PrivateLinkConnectionStateResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.web.kotlin.outputs.ArmIdWrapperResponse.Companion.toKotlin as armIdWrapperResponseToKotlin
import com.pulumi.azurenative.web.kotlin.outputs.PrivateLinkConnectionStateResponse.Companion.toKotlin as privateLinkConnectionStateResponseToKotlin

/**
 * Builder for [WebAppPrivateEndpointConnectionSlot].
 */
@PulumiTagMarker
public class WebAppPrivateEndpointConnectionSlotResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppPrivateEndpointConnectionSlotArgs =
        WebAppPrivateEndpointConnectionSlotArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppPrivateEndpointConnectionSlotArgsBuilder.() -> Unit) {
        val builder = WebAppPrivateEndpointConnectionSlotArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebAppPrivateEndpointConnectionSlot {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppPrivateEndpointConnectionSlot(builtJavaResource)
    }
}

/**
 * Remote Private Endpoint Connection ARM resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2023-01-01, 2023-12-01.
 * ## Example Usage
 * ### Approves or rejects a private endpoint connection for a site.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webAppPrivateEndpointConnectionSlot = new AzureNative.Web.WebAppPrivateEndpointConnectionSlot("webAppPrivateEndpointConnectionSlot", new()
 *     {
 *         Name = "testSite",
 *         PrivateEndpointConnectionName = "connection",
 *         PrivateLinkServiceConnectionState = new AzureNative.Web.Inputs.PrivateLinkConnectionStateArgs
 *         {
 *             ActionsRequired = "",
 *             Description = "Approved by admin.",
 *             Status = "Approved",
 *         },
 *         ResourceGroupName = "rg",
 *         Slot = "stage",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewWebAppPrivateEndpointConnectionSlot(ctx, "webAppPrivateEndpointConnectionSlot", &web.WebAppPrivateEndpointConnectionSlotArgs{
 * 			Name:                          pulumi.String("testSite"),
 * 			PrivateEndpointConnectionName: pulumi.String("connection"),
 * 			PrivateLinkServiceConnectionState: &web.PrivateLinkConnectionStateArgs{
 * 				ActionsRequired: pulumi.String(""),
 * 				Description:     pulumi.String("Approved by admin."),
 * 				Status:          pulumi.String("Approved"),
 * 			},
 * 			ResourceGroupName: pulumi.String("rg"),
 * 			Slot:              pulumi.String("stage"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot;
 * import com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlotArgs;
 * import com.pulumi.azurenative.web.inputs.PrivateLinkConnectionStateArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webAppPrivateEndpointConnectionSlot = new WebAppPrivateEndpointConnectionSlot("webAppPrivateEndpointConnectionSlot", WebAppPrivateEndpointConnectionSlotArgs.builder()
 *             .name("testSite")
 *             .privateEndpointConnectionName("connection")
 *             .privateLinkServiceConnectionState(PrivateLinkConnectionStateArgs.builder()
 *                 .actionsRequired("")
 *                 .description("Approved by admin.")
 *                 .status("Approved")
 *                 .build())
 *             .resourceGroupName("rg")
 *             .slot("stage")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppPrivateEndpointConnectionSlot connection /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/privateEndpointConnections/{privateEndpointConnectionName}
 * ```
 */
public class WebAppPrivateEndpointConnectionSlot internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot,
) : KotlinCustomResource(javaResource, WebAppPrivateEndpointConnectionSlotMapper) {
    /**
     * Private IPAddresses mapped to the remote private endpoint
     */
    public val ipAddresses: Output<List<String>>?
        get() = javaResource.ipAddresses().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0
                })
            }).orElse(null)
        })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * PrivateEndpoint of a remote private endpoint connection
     */
    public val privateEndpoint: Output<ArmIdWrapperResponse>?
        get() = javaResource.privateEndpoint().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 -> armIdWrapperResponseToKotlin(args0) })
            }).orElse(null)
        })

    /**
     * The state of a private link connection
     */
    public val privateLinkServiceConnectionState: Output<PrivateLinkConnectionStateResponse>?
        get() = javaResource.privateLinkServiceConnectionState().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    privateLinkConnectionStateResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppPrivateEndpointConnectionSlotMapper :
    ResourceMapper<WebAppPrivateEndpointConnectionSlot> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot::class == javaResource::class

    override fun map(javaResource: Resource): WebAppPrivateEndpointConnectionSlot =
        WebAppPrivateEndpointConnectionSlot(
            javaResource as
                com.pulumi.azurenative.web.WebAppPrivateEndpointConnectionSlot,
        )
}

/**
 * @see [WebAppPrivateEndpointConnectionSlot].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppPrivateEndpointConnectionSlot].
 */
public suspend fun webAppPrivateEndpointConnectionSlot(
    name: String,
    block: suspend WebAppPrivateEndpointConnectionSlotResourceBuilder.() -> Unit,
): WebAppPrivateEndpointConnectionSlot {
    val builder = WebAppPrivateEndpointConnectionSlotResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppPrivateEndpointConnectionSlot].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppPrivateEndpointConnectionSlot(name: String): WebAppPrivateEndpointConnectionSlot {
    val builder = WebAppPrivateEndpointConnectionSlotResourceBuilder()
    builder.name(name)
    return builder.build()
}
